#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   magic
version:                1.1.1
visibility:             public
id:                     magic-1.1.1-Lw8vN6ezwdX92tng4mYHAy
key:                    magic-1.1.1-Lw8vN6ezwdX92tng4mYHAy
license:                BSD-3-Clause
copyright:              Copyright (c) 2005-2009 John Goerzen
maintainer:             Philippe <philippedev101@gmail.com>
author:                 John Goerzen
homepage:               https://github.com/philippedev101/magic-haskell
synopsis:               Interface to C file/magic library
description:
    This package provides a Haskell interface to the C libmagic library.
    With it, you can determine the type of a file by examining its contents
    rather than its name.  The Haskell interface provides a full-featured
    binding.

    Note: this package requires the C libmagic library (part of the @file@
    package) and its development headers to be installed at build time.

category:               Text
abi:                    f5a3a30adb11e3a937ca3e677604af85
exposed:                True
exposed-modules:
    Magic Magic.Data Magic.Init Magic.Operations Magic.Types

hidden-modules:         Magic.Utils Magic.TypesLL
import-dirs:            /usr/lib/ghc-9.6.6/site-local/magic-1.1.1
library-dirs:           /usr/lib/ghc-9.6.6/site-local/magic-1.1.1 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/magic-1.1.1 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-magic
hs-libraries:           HSmagic-1.1.1-Lw8vN6ezwdX92tng4mYHAy
extra-libraries:        magic
extra-libraries-static: magic seccomp zstd lzma bz2 z
include-dirs:           /usr/include
depends:                base-4.18.2.1
haddock-interfaces:     /usr/share/doc/haskell-magic/html/magic.haddock
haddock-html:           /usr/share/doc/haskell-magic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

